@@ -177,10 +177,18 @@ class Beam(object):
             json_node['associated_issues'])
 
     def iter_files(self):
-        """Iterate the beam files, yielding :class:`.File` objects"""
+        """Iterate the beam files one by one, yielding :class:`.File` objects
+        This function might be slow when used with beams containing large number
+        of file. Consider using :func:`.get_files` instead."""
         for id_ in self._file_ids:
             yield self._scotty.get_file(id_)
 
+    def get_files(self, filter_=None):
+        """Get a list of :class:`.File` instances representing the beam files.
+
+        :ivar filter_: Optional filter string. When given, only files which their name contains the filter will be returned."""
+        return self._scotty.get_files(self.id, filter_)
+
     def set_comment(self, comment):
         data = {'beam': {'comment': comment}}
         response = self._scotty.session.put(
@@ -225,6 +233,9 @@ class Scotty(object):
     def session(self):
         return self._session
 
+    def __del__(self):
+        self._session.close()
+
     @property
     def url(self):
         return self._url
@@ -271,7 +282,7 @@ class Scotty(object):
 
         return beam_id
 
-    def initiate_beam(self, user, host, directory, password=None, rsa_key=None, email=None, beam_type=None):
+    def initiate_beam(self, user, host, directory, password=None, rsa_key=None, email=None, beam_type=None, stored_key=None):
         """Order scotty to beam the specified directory from the specified host.
 
         :param str user: The username in the remote machine.
@@ -281,12 +292,22 @@ class Scotty(object):
         :param str rsa_key: RSA private key for authentication.
         :param str email: Your email. If unspecified, the initiator of the beam will be anonymous.
         :param str beam_type: ID of the beam type as defined in Scotty.
+        :param str stored_key: An ID of a key stored in Scotty.
 
-        Either `password` or `rsa_key` should be specified, but no both.
+        Either `password`, `rsa_key` or `stored_key` should be specified, but only one of them.
 
         :return: the beam id."""
-        if (password and rsa_key) or not (password or rsa_key):
-            raise Exception("Either password or rsa_key should be specified")
+        if len([x for x in (password, rsa_key, stored_key) if x]) != 1:
+            raise Exception("Either password, rsa_key or stored_key should be specified")
+
+        if rsa_key:
+            auth_method = 'rsa'
+        elif password:
+            auth_method = 'password'
+        elif stored_key:
+            auth_method = 'stored_key'
+        else:
+            raise Exception()
 
 
         beam = {
@@ -294,9 +315,10 @@ class Scotty(object):
             'host': host,
             'user': user,
             'ssh_key': rsa_key,
+            'stored_key': stored_key,
             'password': password,
             'type': beam_type,
-            'auth_method': 'rsa' if rsa_key else 'password'
+            'auth_method': auth_method
         }
 
         if email:
@@ -335,6 +357,13 @@ class Scotty(object):
         json_response = response.json()
         return Beam.from_json(self, json_response['beam'])
 
+    def get_files(self, beam_id, filter_):
+        response = self._session.get(
+            "{0}/files".format(self._url),
+            params={"beam_id": beam_id, "filter": filter_})
+        response.raise_for_status()
+        return [File.from_json(self._session, f) for f in response.json()['files']]
+
     def get_file(self, file_id):
         """Retrieve details about the specified file.
 
